@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.cpp,v 1.4 2006/08/26 13:23:30 cepek Exp $
+ *  $Id: network.cpp,v 1.7 2006/09/22 15:45:31 cepek Exp $
  */
 
 #include <fstream>
@@ -45,6 +45,10 @@ using namespace GaMaLib;
 typedef GNU_gama::List<GNU_gama::Cluster<Observation>*> ClusterList;
 typedef GNU_gama::Cluster<Observation>                  Cluster;
 
+namespace 
+{
+  const char* UNKNOWN_ALGORITHM="### network.cpp : unknown algorithm ###";
+}
 
 LocalNetwork::LocalNetwork()        
   : pocbod_(0), tst_redbod_(false), pocmer_(0), tst_redmer_(false),
@@ -315,11 +319,59 @@ void LocalNetwork::project_equations()
     }
 
   if (AdjBaseFull* full = dynamic_cast<AdjBaseFull*>(least_squares))
-    full->reset(A, b);
+    {
+      full->reset(A, b);
+    }
+  else if (AdjBaseSparse* sparse = dynamic_cast<AdjBaseSparse*>(least_squares))
+    {
+      /*********************************/
+      /*  reset AdjInputData structure */
+      /*********************************/
+
+      // design matrix
+
+      input.set_mat(Asp);
+      Asp = 0;
+      
+      // ---  cofactors  --------------------------------------------------
+
+      Index count = 0;   // number of diagonal blocks
+      Index msize = 0;   // memory size 
+
+      for (ClusterList::const_iterator 
+             cluster=OD.clusters.begin(); cluster!=OD.clusters.end(); ++cluster)
+        if (const Index N = (*cluster)->activeObs())
+        {
+          Index W = (*cluster)->covariance_matrix.bandWidth();
+          count++;
+          msize += 1+(N+N-W)*(W+1)/2;   // += number of band matrix elements
+        }
+
+      GNU_gama::BlockDiagonal<> *bd = new GNU_gama::BlockDiagonal<>(count, msize);
+
+      for (ClusterList::const_iterator 
+             cluster=OD.clusters.begin(); cluster!=OD.clusters.end(); ++cluster)
+        if (const Index N = (*cluster)->activeObs())
+        {
+          CovMat C = (*cluster)->activeCov();
+          C /= (m_0_apr_*m_0_apr_);        // covariances ==> cofactors
+          bd->add_block(N, C.bandWidth(), C.begin());
+        }
+
+      input.set_cov(bd);
+      bd = 0;
+      
+      // ---  right-hand side  --------------------------------------------
+
+      GNU_gama::Vec<> bb(b.dim());
+      for (Index i=1; i<=b.dim(); i++) bb(i) = rhs_(i);
+      input.set_rhs(bb);     // right-hand side before homogenization
+
+      sparse->reset(&input);
+    }
   else
     {
-      std::cerr << "\n### network.cpp : unknown algorithm ###\n\n";
-      std::exit(0);
+      throw GaMaLib::Exception(UNKNOWN_ALGORITHM);
     }
 
   //--ofstream opr("A_scaled.bin", ios_base::trunc); 
@@ -869,7 +921,7 @@ void LocalNetwork::vyrovnani_()
   if (sum_points()      == 0)
     throw GaMaLib::Exception(T_GaMa_No_points_available);
 
-  least_squares->solve();
+  /* least_squares->solve(); ... removed in 1.9.01a */
 
   tst_vyrovnani_ = true;
 
@@ -919,8 +971,10 @@ void LocalNetwork::vyrovnani_()
       }
   }
 
+  if (AdjBaseFull* full = dynamic_cast<AdjBaseFull*>(least_squares))
   { /* ----------------------------------------------------------------- */
-    r = least_squares->residuals();
+    // r = least_squares->residuals();
+    r = full->residuals();
     suma_pvv_ = 0;
 
     Double tmp;
@@ -958,6 +1012,16 @@ void LocalNetwork::vyrovnani_()
           ind_0 += N;
         }
   }
+  else if (AdjBaseSparse* sparse = dynamic_cast<AdjBaseSparse*>(least_squares))
+    {
+      r = sparse->residuals();
+      suma_pvv_ = sparse->sum_of_squares();
+    }
+  else
+    {
+      throw GaMaLib::Exception(UNKNOWN_ALGORITHM);
+    }
+  
 
   { /* ----------------------------------------------------------------- */
     sigma_L.reset(pocmer_);
