@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: adj.cpp,v 1.2 2006/08/25 15:52:35 cepek Exp $
+ *  $Id: adj.cpp,v 1.4 2007/01/15 09:07:48 cepek Exp $
  */
 
 #include <gnu_gama/adj/adj.h>
@@ -278,6 +278,9 @@ void Adj::init_least_squares()
 
   switch (algorithm_) 
     {
+    case envelope:
+      least_squares = new AdjEnvelope<double, Index, Exception::matvec>;
+      break;
     case svd: 
       least_squares = new AdjSVD<double, Exception::matvec>;
       break;
@@ -290,12 +293,12 @@ void Adj::init_least_squares()
     default:
       throw Exception::adjustment("### unknown algorithm");
     }
-
+  
   if (const IntegerList<>* p = data->minx())
     {
       delete minx;
       minx_dim = 0;
-
+      
       if (Index N = p->dim())
         {
           minx_dim = N;
@@ -306,77 +309,82 @@ void Adj::init_least_squares()
               *q++ = *i;
             }
         }
-
-      switch (algorithm_) 
-        {
-        case svd: 
-        case gso: 
-        case cholesky: 
-          least_squares->min_x(minx_dim, minx);
-          break;
-        default:
-          throw Exception::adjustment("### unknown algorithm");
-    }
       
+      least_squares->min_x(minx_dim, minx);
     }
 
-  A_dot.reset(data->A->rows(), data->A->columns());
-  A_dot.set_zero();
-  b_dot.reset(data->A->rows());
-
-  for (std::size_t k=1; k<=data->A->rows(); k++)
+  if (AdjBaseSparse* sprs = dynamic_cast<AdjBaseSparse*>(least_squares))
     {
-      double* n = data->A->begin(k);
-      double* e = data->A->end  (k);
-      for(size_t* i=data->A->ibegin(k) ; n!=e; n++, i++)  A_dot(k,*i) = *n; 
-     }
+      sprs->reset(data);
 
-  for (std::size_t i, j, dim, width, r=0, b=1; 
-       b<=data->pcov->blocks(); b++, r += dim)
+      x_   = least_squares->unknowns();
+      r_   = least_squares->residuals();
+      rtr_ = least_squares->sum_of_squares();
+    }
+  else if (AdjBaseFull* full = dynamic_cast<AdjBaseFull*>(least_squares))
     {
-      dim   = data->pcov->dim(b);
-      width = data->pcov->width(b);
-      CovMat<> C(dim, width);
-
-      const double *p = data->pcov->begin(b), *e = data->pcov->end(b);
-      CovMat<>::iterator c = C.begin();
-      while (p != e) *c++ = *p++;
-      choldec(C);
-
-      Vec<> t(dim);
-      for (i=1; i<=dim; i++) t(i) = data->prhs(r+i);
-      forwardSubstitution(C, t);
-      for (i=1; i<=dim; i++) b_dot(r+i) = t(i);
-
-      for (j=1; j<=data->A->columns(); j++)
+      A_dot.reset(data->A->rows(), data->A->columns());
+      A_dot.set_zero();
+      b_dot.reset(data->A->rows());
+      
+      for (std::size_t k=1; k<=data->A->rows(); k++)
         {
-          for (i=1; i<=dim; i++) t(i) = A_dot(r+i,j);
+          double* n = data->A->begin(k);
+          double* e = data->A->end  (k);
+          for(size_t* i=data->A->ibegin(k) ; n!=e; n++, i++)  A_dot(k,*i) = *n;
+        }
+      
+      for (std::size_t i, j, dim, width, r=0, b=1; 
+           b<=data->pcov->blocks(); b++, r += dim)
+        {
+          dim   = data->pcov->dim(b);
+          width = data->pcov->width(b);
+          CovMat<> C(dim, width);
+          
+          const double *p = data->pcov->begin(b), *e = data->pcov->end(b);
+          CovMat<>::iterator c = C.begin();
+          while (p != e) *c++ = *p++;
+          choldec(C);
+          
+          Vec<> t(dim);
+          for (i=1; i<=dim; i++) t(i) = data->prhs(r+i);
           forwardSubstitution(C, t);
-          for (i=1; i<=dim; i++) A_dot(r+i,j) = t(i);
+          for (i=1; i<=dim; i++) b_dot(r+i) = t(i);
+          
+          for (j=1; j<=data->A->columns(); j++)
+            {
+              for (i=1; i<=dim; i++) t(i) = A_dot(r+i,j);
+              forwardSubstitution(C, t);
+              for (i=1; i<=dim; i++) A_dot(r+i,j) = t(i);
+            }
+        }
+      
+      full->reset(A_dot, b_dot);
+
+      const Vec<>& v = least_squares->residuals();
+      rtr_ = trans(v)*v;
+
+      x_   = least_squares->unknowns();
+      
+      const Vec<>& rhs = data->rhs();
+      r_.reset(data->A->rows());
+      for (Index i=1; i<=r_.dim(); i++)
+        {
+          double* b = data->A->begin(i);
+          double* e = data->A->end(i);
+          Index * n = data->A->ibegin(i);
+          double  s = 0;
+          while (b != e)
+            s += *b++ * x_(*n++);
+          
+          r_(i) = s - rhs(i);
         }
     }
-
-  least_squares->reset(A_dot, b_dot);
-
-  x_   = least_squares->unknowns();
-
-  const Vec<>& v = least_squares->residuals();
-  rtr_ = trans(v)*v;
-
-  const Vec<>& rhs = data->rhs();
-  r_.reset(data->A->rows());
-  for (Index i=1; i<=r_.dim(); i++)
+  else
     {
-      double* b = data->A->begin(i);
-      double* e = data->A->end(i);
-      Index * n = data->A->ibegin(i);
-      double  s = 0;
-      while (b != e)
-          s += *b++ * x_(*n++);
-
-      r_(i) = s - rhs(i);
+      throw Exception::adjustment("### unknown algorithm");
     }
-
+  
   solved = true;
 }
 
@@ -386,6 +394,7 @@ void Adj::set_algorithm(Adj::algorithm alg)
 {
   switch (alg)
     {
+    case envelope:
     case svd:
     case gso:
     case cholesky:
