@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: localnetwork.cpp,v 1.3 2006/08/26 13:23:30 cepek Exp $
+ *  $Id: localnetwork.cpp,v 1.6 2006/11/19 15:16:15 cepek Exp $
  */
 
 
@@ -78,7 +78,7 @@ void LocalNetworkXML::write(std::ostream& out) const
       out << "   axes-xy=\""; 
       switch (netinfo->PD.local_coordinate_system)
         {
-        case   1: out << "ne"; break;
+        case   1: out << "en"; break;
         case   2: out << "nw"; break;
         case   4: out << "se"; break;
         case   8: out << "ws"; break;
@@ -273,19 +273,23 @@ void LocalNetworkXML::std_dev_summary(std::ostream& out) const
     const int dof = netinfo->degrees_of_freedom();
     float test=0, lower=0, upper=0; 
 
+    test  = netinfo->m_0() / netinfo->apriori_m_0();
     if (dof)
       if (netinfo->m_0_aposteriori())
         {
           const double alfa_pul = (1 - netinfo->conf_pr())/2;
-          test  = netinfo->m_0() / netinfo->apriori_m_0();
           lower = sqrt(GNU_gama::Chi_square(1-alfa_pul,dof)/dof);
           upper = sqrt(GNU_gama::Chi_square(  alfa_pul,dof)/dof);
         }
+      else
+        {
+          out << "   <!-- no test for apriori standard deviation -->\n";
+        }
 
     tagnl(out, "ratio",  test);
     tagnl(out, "lower",  lower);
     tagnl(out, "upper",  upper);
-    if (lower < test && test < upper)
+    if (lower < test && test < upper || netinfo->m_0_apriori())
       out << "   <passed/>\n\n";
     else
       out << "   <failed/>\n\n";
@@ -300,6 +304,8 @@ void LocalNetworkXML::std_dev_summary(std::ostream& out) const
 
 void LocalNetworkXML::coordinates(std::ostream& out) const
 {
+  const int y_sign = Consistent(netinfo->PD) ? +1 : -1;
+  
   out << "\n<coordinates>\n";
 
   out.setf(ios_base::fixed, ios_base::floatfield);
@@ -325,7 +331,7 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
       if (bxy)
         {
           const double x = (p.x()+X(p.index_x())/1000);
-          const double y = (p.y()+X(p.index_y())/1000);
+          const double y = (p.y()+X(p.index_y())/1000)*y_sign;
           tagsp(out, "x", x);
           tagsp(out, "y", y);
         }
@@ -362,7 +368,7 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
               cy = "Y";
             }
           const double x = p.x();
-          const double y = p.y();
+          const double y = p.y()*y_sign;
           tagsp(out, cx, x);
           tagsp(out, cy, y);
         }
@@ -404,7 +410,7 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
               cy = "Y";
             }
           const double x = (p.x()+X(p.index_x())/1000);
-          const double y = (p.y()+X(p.index_y())/1000);
+          const double y = (p.y()+X(p.index_y())/1000)*y_sign;
           tagsp(out, cx, x);
           tagsp(out, cy, y);
           ind[++dim] = p.index_x();
@@ -460,8 +466,8 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
 
 
 void  LocalNetworkXML::orientation_shifts(std::ostream& out,
-                                          std::vector<Index>& ind,
-                                          Index& dim) const
+                                          std::vector<GNU_gama::Index>& ind,
+                                          GNU_gama::Index& dim) const
 {
   out << "\n<orientation-shifts>\n";
 
